==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ms-MY/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Hari',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Laporan Aset Tamat.',
    'Expiring_Licenses_Report' => 'Laporan Lesen Berakhir.',
    'Item_Request_Canceled' => 'Permintaan Item Dibatalkan',
    'Item_Requested' => 'Item yang diminta',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Laporan Inventori Rendah',
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di laman web',
    'a_user_requested' => 'Seorang pengguna telah meminta item di laman web',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Nama Aksesori',
    'additional_notes' => 'Nota tambahan',
    'admin_has_created' => 'Pentadbir telah membuat akaun untuk anda di: laman web web.',
    'asset' => 'Harta',
    'asset_name' => 'Nama Harta',
    'asset_requested' => 'Aset diminta',
    'asset_tag' => 'Tag Harta',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Selamat sejahtera,',
    'canceled' => 'Dibatalkan',
    'checkin_date' => 'Tarikh daftar masuk',
    'checkout_date' => 'Tarikh Agihan',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aset tersebut.',
    'click_to_confirm' => 'Sila klik pada pautan berikut untuk mengesahkan akaun web anda:',
    'current_QTY' => 'QTY semasa',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tarikh Periksa Yang Diharapkan',
    'expires' => 'Tamat tempoh',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Saya telah membaca dan bersetuju dengan terma penggunaan, dan telah menerima item ini.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Perkara',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.|Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.',
    'link_to_update_password' => 'Sila klik pada pautan berikut untuk mengemas kini kata laluan web anda:',
    'login' => 'Log masuk:',
    'login_first_admin' => 'Masuk ke pemasangan Snipe-IT baru anda menggunakan kelayakan di bawah ini:',
    'low_inventory_alert' => 'Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah. Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah.',
    'min_QTY' => 'QTY min',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa di bawah nama anda, butiran di bawah.',
    'notes' => 'Nota',
    'password' => 'Kata Laluan',
    'password_reset' => 'Memadam kata laluan',
    'read_the_terms' => 'Sila baca terma penggunaan di bawah.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Diminta',
    'reset_link' => 'Pautan Semula Kata Laluan Anda',
    'reset_password' => 'Klik di sini untuk menetapkan semula kata laluan anda:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Siri',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Pembekal',
    'tag' => 'Tag',
    'test_email' => 'Uji E-mel dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Sistem Pengurusan Asset Snipe-IT. Jika anda mendapat ini, mel sedang berfungsi :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'to_reset' => 'Untuk menetapkan semula kata laluan web anda, lengkapkan borang ini:',
    'type' => 'Taipkan',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat datang ke: web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Kredensial Snipe-IT anda',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ms-MY/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Hari',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Laporan Aset Tamat.',
    'Expiring_Licenses_Report' => 'Laporan Lesen Berakhir.',
    'Item_Request_Canceled' => 'Permintaan Item Dibatalkan',
    'Item_Requested' => 'Item yang diminta',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Laporan Inventori Rendah',
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di laman web',
    'a_user_requested' => 'Seorang pengguna telah meminta item di laman web',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Nama Aksesori',
    'additional_notes' => 'Nota tambahan',
    'admin_has_created' => 'Pentadbir telah membuat akaun untuk anda di: laman web web.',
    'asset' => 'Harta',
    'asset_name' => 'Nama Harta',
    'asset_requested' => 'Aset diminta',
    'asset_tag' => 'Tag Harta',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Selamat sejahtera,',
    'canceled' => 'Dibatalkan',
    'checkin_date' => 'Tarikh daftar masuk',
    'checkout_date' => 'Tarikh Agihan',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aset tersebut.',
    'click_to_confirm' => 'Sila klik pada pautan berikut untuk mengesahkan akaun web anda:',
    'current_QTY' => 'QTY semasa',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tarikh Periksa Yang Diharapkan',
    'expires' => 'Tamat tempoh',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Saya telah membaca dan bersetuju dengan terma penggunaan, dan telah menerima item ini.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Perkara',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.|Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.',
    'link_to_update_password' => 'Sila klik pada pautan berikut untuk mengemas kini kata laluan web anda:',
    'login' => 'Log masuk',
    'login_first_admin' => 'Masuk ke pemasangan Snipe-IT baru anda menggunakan kelayakan di bawah ini:',
    'low_inventory_alert' => 'Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah. Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah.',
    'min_QTY' => 'QTY min',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa di bawah nama anda, butiran di bawah.',
    'notes' => 'Nota',
    'password' => 'Kata Laluan',
    'password_reset' => 'Memadam kata laluan',
    'read_the_terms' => 'Sila baca terma penggunaan di bawah.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Diminta',
    'reset_link' => 'Pautan Semula Kata Laluan Anda',
    'reset_password' => 'Klik di sini untuk menetapkan semula kata laluan anda:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Siri',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Pembekal',
    'tag' => 'Tag',
    'test_email' => 'Uji E-mel dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Sistem Pengurusan Asset Snipe-IT. Jika anda mendapat ini, mel sedang berfungsi :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'to_reset' => 'Untuk menetapkan semula kata laluan web anda, lengkapkan borang ini:',
    'type' => 'Taipkan',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat datang ke: web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Kredensial Snipe-IT anda',
    'mail_sent' => 'Mail sent successfully!',
];
